==> istio-model-v1beta1-6.5.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/TLSMatchAttributesFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface TLSMatchAttributesFluent<A extends TLSMatchAttributesFluent<A>> extends Fluent<A>{
  public A addToDestinationSubnets(Integer index,String item);
  public A setToDestinationSubnets(Integer index,String item);
  public A addToDestinationSubnets(java.lang.String... items);
  public A addAllToDestinationSubnets(Collection<String> items);
  public A removeFromDestinationSubnets(java.lang.String... items);
  public A removeAllFromDestinationSubnets(Collection<String> items);
  public List<String> getDestinationSubnets();
  public String getDestinationSubnet(Integer index);
  public String getFirstDestinationSubnet();
  public String getLastDestinationSubnet();
  public String getMatchingDestinationSubnet(Predicate<String> predicate);
  public Boolean hasMatchingDestinationSubnet(Predicate<String> predicate);
  public A withDestinationSubnets(List<String> destinationSubnets);
  public A withDestinationSubnets(java.lang.String... destinationSubnets);
  public Boolean hasDestinationSubnets();
  public A addToGateways(Integer index,String item);
  public A setToGateways(Integer index,String item);
  public A addToGateways(java.lang.String... items);
  public A addAllToGateways(Collection<String> items);
  public A removeFromGateways(java.lang.String... items);
  public A removeAllFromGateways(Collection<String> items);
  public List<String> getGateways();
  public String getGateway(Integer index);
  public String getFirstGateway();
  public String getLastGateway();
  public String getMatchingGateway(Predicate<String> predicate);
  public Boolean hasMatchingGateway(Predicate<String> predicate);
  public A withGateways(List<String> gateways);
  public A withGateways(java.lang.String... gateways);
  public Boolean hasGateways();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public A addToSniHosts(Integer index,String item);
  public A setToSniHosts(Integer index,String item);
  public A addToSniHosts(java.lang.String... items);
  public A addAllToSniHosts(Collection<String> items);
  public A removeFromSniHosts(java.lang.String... items);
  public A removeAllFromSniHosts(Collection<String> items);
  public List<String> getSniHosts();
  public String getSniHost(Integer index);
  public String getFirstSniHost();
  public String getLastSniHost();
  public String getMatchingSniHost(Predicate<String> predicate);
  public Boolean hasMatchingSniHost(Predicate<String> predicate);
  public A withSniHosts(List<String> sniHosts);
  public A withSniHosts(java.lang.String... sniHosts);
  public Boolean hasSniHosts();
  public A addToSourceLabels(String key,String value);
  public A addToSourceLabels(Map<String,String> map);
  public A removeFromSourceLabels(String key);
  public A removeFromSourceLabels(Map<String,String> map);
  public Map<String,String> getSourceLabels();
  public <K,V>A withSourceLabels(Map<String,String> sourceLabels);
  public Boolean hasSourceLabels();
  public String getSourceNamespace();
  public A withSourceNamespace(String sourceNamespace);
  public Boolean hasSourceNamespace();
  
}

==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/TLSMatchAttributesFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TLSMatchAttributesFluent<A extends TLSMatchAttributesFluent<A>> extends Fluent<A>{
  public A addToDestinationSubnets(int index,String item);
  public A setToDestinationSubnets(int index,String item);
  public A addToDestinationSubnets(java.lang.String... items);
  public A addAllToDestinationSubnets(Collection<String> items);
  public A removeFromDestinationSubnets(java.lang.String... items);
  public A removeAllFromDestinationSubnets(Collection<String> items);
  public List<String> getDestinationSubnets();
  public String getDestinationSubnet(int index);
  public String getFirstDestinationSubnet();
  public String getLastDestinationSubnet();
  public String getMatchingDestinationSubnet(Predicate<String> predicate);
  public Boolean hasMatchingDestinationSubnet(Predicate<String> predicate);
  public A withDestinationSubnets(List<String> destinationSubnets);
  public A withDestinationSubnets(java.lang.String... destinationSubnets);
  public Boolean hasDestinationSubnets();
  public A addToGateways(int index,String item);
  public A setToGateways(int index,String item);
  public A addToGateways(java.lang.String... items);
  public A addAllToGateways(Collection<String> items);
  public A removeFromGateways(java.lang.String... items);
  public A removeAllFromGateways(Collection<String> items);
  public List<String> getGateways();
  public String getGateway(int index);
  public String getFirstGateway();
  public String getLastGateway();
  public String getMatchingGateway(Predicate<String> predicate);
  public Boolean hasMatchingGateway(Predicate<String> predicate);
  public A withGateways(List<String> gateways);
  public A withGateways(java.lang.String... gateways);
  public Boolean hasGateways();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public A addToSniHosts(int index,String item);
  public A setToSniHosts(int index,String item);
  public A addToSniHosts(java.lang.String... items);
  public A addAllToSniHosts(Collection<String> items);
  public A removeFromSniHosts(java.lang.String... items);
  public A removeAllFromSniHosts(Collection<String> items);
  public List<String> getSniHosts();
  public String getSniHost(int index);
  public String getFirstSniHost();
  public String getLastSniHost();
  public String getMatchingSniHost(Predicate<String> predicate);
  public Boolean hasMatchingSniHost(Predicate<String> predicate);
  public A withSniHosts(List<String> sniHosts);
  public A withSniHosts(java.lang.String... sniHosts);
  public Boolean hasSniHosts();
  public A addToSourceLabels(String key,String value);
  public A addToSourceLabels(Map<String,String> map);
  public A removeFromSourceLabels(String key);
  public A removeFromSourceLabels(Map<String,String> map);
  public Map<String,String> getSourceLabels();
  public <K,V>A withSourceLabels(Map<String,String> sourceLabels);
  public Boolean hasSourceLabels();
  public String getSourceNamespace();
  public A withSourceNamespace(String sourceNamespace);
  public Boolean hasSourceNamespace();
  
}
